/* This script creates a database for use with the example MySQL realm
 * in /etc/tomcat/server.xml.  To execute it you should pipe this file
 * to the MySQL client:
 *
 *  mysql -uroot -p < /usr/share/doc/tomcat-4.1.27/MySQL-REALM.sql
 *
 * Note that the database server must be accepting TCP connections for
 * Tomcat to be able to connect to it.  This is enabled by removing
 * the 'skip-networking' option from /etc/my.cnf.
 */

/* Create the database, named as specified by the connectionURL
 * attribute of the <Realm/> element in your server.xml.
 */
CREATE DATABASE authority;
USE authority;

/* Create the tables, named as specified by the userTable and
 * userRoleTable attributes of your realm.  The rows are named as
 * specified the userNameCol, userCredCol and roleNameCol attributes
 * of your realm.  The rows can be CHAR or VARCHAR, and any size you
 * desire.
 */
CREATE TABLE users (
  user_name CHAR(32) NOT NULL,
  user_pass CHAR(32) NOT NULL,
  PRIMARY KEY (user_name)
);
CREATE TABLE roles (
  user_name CHAR(32) NOT NULL REFERENCES users (user_name),
  role_name CHAR(32) NOT NULL
);

/* Allow Tomcat to connect to the database server with the username
 * and password specified by the connectionName and connectionPassword
 * attributes, and allow access to all tables in the authority database.
 */
GRANT SELECT
  ON users
  TO authority@localhost.localdomain
  IDENTIFIED BY 'PaSsW0Rd';
GRANT SELECT
  ON roles
  TO authority@localhost.localdomain
  IDENTIFIED BY 'PaSsW0Rd';

/* Create an example user with no roles.
 */
INSERT INTO users VALUES ('testuser', 'testpassword');

/* Uncomment the follwing to create an example user with the 'admin'
 * and 'manager' roles.
 */
-- INSERT INTO users VALUES ('testadmin', 'testpassword');
-- INSERT INTO roles VALUES ('testadmin', 'admin');
-- INSERT INTO roles VALUES ('testadmin', 'manager');
